"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Consumers = void 0;
const utils_1 = require("../utils");
/* Browser-based consumers implementation */
exports.Consumers = {
    mixpanel: {
        test: () => window.mixpanel && window.mixpanel.__loaded,
        identify: (userId, userProperties) => {
            window.mixpanel.identify(userId);
            if (userProperties) {
                window.mixpanel.people.set(userProperties);
            }
        },
        track: (eventName, eventProperties) => {
            window.mixpanel.track(eventName, eventProperties);
        },
    },
    heap: {
        test: () => window.heap && window.heap.track,
        identify: (userId, userProperties) => {
            window.heap.identify(userId);
            if (userProperties) {
                window.heap.addUserProperties(userProperties);
            }
        },
        track: (eventName, eventProperties) => {
            window.heap.track(eventName, eventProperties);
        },
    },
    amplitude: {
        test: () => window.amplitude && window.amplitude.options,
        identify: (userId, userProperties) => {
            window.amplitude.getInstance().setUserId(userId);
            if (userProperties) {
                window.amplitude.getInstance().setUserProperties(userProperties);
            }
        },
        track: (eventName, eventProperties) => {
            window.amplitude.getInstance().logEvent(eventName, eventProperties);
        },
    },
    outbound: {
        // This is Zendesk Connect
        test: () => window.outbound && window.outbound.track,
        identify: (userId, userProperties) => {
            window.outbound.identify(userId, userProperties);
        },
        track: (eventName, eventProperties) => {
            window.outbound.track(eventName, eventProperties);
        },
    },
    googleAnalytics: {
        test: () => !!window.ga,
        identify: (userId, userProperties = {}) => {
            userProperties.userId = userId;
            window.ga('set', userProperties);
        },
        track: (eventName, eventProperties = {}) => {
            eventProperties.eventCategory = eventProperties.eventCategory ? eventProperties.eventCategory : 'All';
            eventProperties.eventAction = eventName;
            eventProperties.hitType = 'event';
            window.ga('send', eventProperties);
        },
    },
    snowplow: {
        // TODO: Improvements to use multiple schemas
        test: () => !!window.snowplow && !!window.snowplowschema,
        identify: (userId, _ = {}) => {
            window.snowplow('setUserId', userId);
        },
        track: (eventName, eventProperties = {}) => {
            eventProperties.event = eventName;
            const selfDescribingEvent = {
                schema: window.snowplowschema,
                data: eventProperties,
            };
            window.snowplow('trackSelfDescribingEvent', selfDescribingEvent);
        },
    },
    sendinblue: {
        test: () => window.sendinblue,
        identify: (userId, userProperties) => {
            window.sendinblue.identify(userId, userProperties);
        },
        track: (eventName, eventProperties) => {
            window.sendinblue.track(eventName, eventProperties);
        },
    },
    ga4: {
        test: () => !!window.gtag,
        identify: (userId, userProperties = {}) => {
            userProperties.user_id = userId;
            window.gtag('set', 'user_properties', userProperties);
        },
        track: (eventName, eventProperties) => {
            window.gtag('event', eventName.replace(/[.\-\s]+/g, '_'), eventProperties);
        },
    },
    indicative: {
        test: () => window.Indicative,
        identify: (userId, _ = {}) => {
            window.Indicative.setUniqueID(userId, true);
        },
        track: (eventName, eventProperties) => {
            window.Indicative.buildEvent(eventName, eventProperties);
        },
    },
    hyperdx: {
        test: () => window.HyperDX,
        identify: (userId, _ = {}) => {
            window.HyperDX.setGlobalAttributes({
                userId: userId,
            });
        },
        track: (eventName, eventProperties) => {
            window.HyperDX.addAction(eventName, eventProperties);
        },
    },
    matomo: {
        test: () => !!window.Piwik,
        identify: (userId, _ = {}) => {
            window.Piwik.getAsyncTracker().setUserId(userId);
        },
        track: (eventName, eventProperties) => {
            window.Piwik.getAsyncTracker().trackEvent(eventProperties.eventCategory, eventName, eventName, 1, (0, utils_1.prepareMatomoDimensions)(eventProperties));
        },
    },
};
//# sourceMappingURL=browser.js.map