/**
 * Event consumer configuration object.
 * It is mandatory to have an event configuration for a consumer, but allow/deny properties are optional.
 * Consumer configuration having just a consumer name implies that all events will be sent to that consumer.
 * Granular control of the consumer can be achieved via allow/deny configuration.
 * For certain consumers we can limit the event digestion, using the deny property we can define which event should not be sent to
 * the consumer.
 * Allow/deny properties can have,
 * - *: affects all events
 * - specific events by namespace which only affects what is matching
 * ie: If we deny 'app.user.' namespace, all events starting with that namespace will get affected
 * Usage:
 * 1. { name: 'mixpanel' } --> All events will be sent
 * 2. { name: 'mixpanel', allow: [] } --> No events will be allowed
 * 3. { name: 'mixpanel', allow: [ '*' ] } --> All events will be sent
 * 4. { name: 'mixpanel', allow: [ 'site.' ] } --> All site events will be sent
 * 5. { name: 'mixpanel', allow: [ '*' ], deny: [ 'site.login.', 'app.user.' ] } --> Do not send site.login.* and app.user.* events
 * 6. { name: 'mixpanel', deny: [ 'user.collab.' ] } --> Do not send user.collab.* events
 * 7. { name: 'mixpanel', denyParameters: [ {eventId: 'user.login.failed', parameters: ['location'] } ] } --> Do not send location parameter with user.login.failed event
 */
export type EventConfiguration = {
    name: string;
    allow?: string[];
    deny?: string[];
    denyParameters?: any;
};
/**
 * Siddi event consumer type
 * test: Function which returnes a boolean based on consumer is initialized and active
 * track: Tracking function implementation based on consumer API
 * identify: User identification function implementation based on consumer API
 */
export interface Consumer {
    test: Function;
    identify: (userId: string, userProperties: object) => void;
    track: (eventName: string, eventProperties: object) => void;
    init?: Function;
}
/**
 * Siddi - An abstract event consumer
 * This implements a more abstract version of a event consumer which will send out events to multiple consumers
 * which are already loaded and initialized by the application which uses this.
 */
export declare class Siddi {
    private consumerConfig;
    private _consumers;
    /**
     * Default consumer configuration
     */
    private readonly defaultConsumerRule;
    /**
     * Current status of the event consumers
     */
    private consumerStatus;
    /**
     * Current user
     */
    private user;
    /**
     * Constructor
     * @param consumerConfig Event configuration object
     */
    constructor(consumerConfig: EventConfiguration[], _consumers?: Record<string, Consumer>);
    /**
     * Identify the current user with the event consumers. After the identification
     * and event being tracked will automatically belong this user.
     * @param userId Current user id
     * @param userProperties any additional properties of the user
     */
    identify(userId: string, userProperties?: any): void;
    /**
     * Track a given event
     * @param eventName meaningfull name for the event
     * @param eventProperties additional event properties
     */
    track(eventName: string, eventProperties: any): void;
    /**
     * Check whether the event should be sent to the given consumer.
     * 1. { name: 'mixpanel' } --> All events will be sent
     * 2. { name: 'mixpanel', allow: [] } --> No events will be allowed
     * 3. { name: 'mixpanel', allow: [ '*' ] } --> All events will be sent
     * 4. { name: 'mixpanel', allow: [ 'site.' ] } --> All site events will be sent
     * 5. { name: 'mixpanel', allow: [ '*' ], deny: [ 'site.login.', 'app.user.' ] } --> Do not send site.login.* and app.user.* events
     * 6. { name: 'mixpanel', deny: [ 'user.collab.' ] } --> Do not send user.collab.* events
     * @param consumer target event consumer
     * @param eventName event name
     */
    private shouldTrack;
}
export { Consumers as BrowserConsumers } from './consumers/browser';
export { Consumers as ServerConsumers } from './consumers/node';
