"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerConsumers = exports.BrowserConsumers = exports.Siddi = void 0;
const browser_1 = require("./consumers/browser");
/**
 * Siddi - An abstract event consumer
 * This implements a more abstract version of a event consumer which will send out events to multiple consumers
 * which are already loaded and initialized by the application which uses this.
 */
class Siddi {
    /**
     * Constructor
     * @param consumerConfig Event configuration object
     */
    constructor(consumerConfig, _consumers = browser_1.Consumers) {
        this.consumerConfig = consumerConfig;
        this._consumers = _consumers;
        /**
         * Default consumer configuration
         */
        this.defaultConsumerRule = { allow: ['*'], deny: [] };
        /**
         * Current status of the event consumers
         */
        this.consumerStatus = {};
        this.user = { id: '', properties: undefined };
        Object.values(this._consumers).forEach(consumer => consumer.init && consumer.init());
    }
    /**
     * Identify the current user with the event consumers. After the identification
     * and event being tracked will automatically belong this user.
     * @param userId Current user id
     * @param userProperties any additional properties of the user
     */
    identify(userId, userProperties) {
        this.user.id = userId;
        this.user.properties = userProperties;
    }
    /**
     * Track a given event
     * @param eventName meaningfull name for the event
     * @param eventProperties additional event properties
     */
    track(eventName, eventProperties) {
        this.consumerConfig.forEach(config => {
            // Assign event properties to a new obeject
            let filteredEventProperties = Object.assign({}, eventProperties);
            // consumer name must exist, else ignore it
            if (config.name && this._consumers[config.name] && this.shouldTrack(config, eventName)) {
                // If no consumer status tracking exist, check it first
                if (this.consumerStatus[config.name]) {
                    // Status exists, re-ckeck if consumer is enabled and initialized, if it is not enabled
                    if (!this.consumerStatus[config.name].enabled && this._consumers[config.name].test()) {
                        this.consumerStatus[config.name].enabled = true;
                    }
                }
                else {
                    // Add status info of the new consumer
                    if (this._consumers[config.name].test()) {
                        this.consumerStatus[config.name] = { enabled: true, identified: false };
                    }
                    else {
                        this.consumerStatus[config.name] = { enabled: false, identified: false };
                    }
                }
                // Exclude sending event parameters for particular event
                // when those defined in denyParameters config
                if (eventProperties && config.denyParameters) {
                    config.denyParameters.some(function (element, index) {
                        if (element.eventId === eventName) {
                            config.denyParameters[index].parameters.forEach(function (property) {
                                delete filteredEventProperties[property];
                            });
                        }
                    });
                }
                // Track the event only if consumer is in enabled status
                // We do not send tracking data to consumers knowingly that they would fail
                if (this.consumerStatus[config.name].enabled) {
                    if (this.user.id && !this.consumerStatus[config.name].identified) {
                        // Identify the user
                        this._consumers[config.name].identify(this.user.id, this.user.properties);
                        this.consumerStatus[config.name].identified = true;
                    }
                    new Promise(resolve => {
                        this._consumers[config.name].track(eventName, filteredEventProperties);
                        resolve(true);
                    });
                }
            }
        });
    }
    /**
     * Check whether the event should be sent to the given consumer.
     * 1. { name: 'mixpanel' } --> All events will be sent
     * 2. { name: 'mixpanel', allow: [] } --> No events will be allowed
     * 3. { name: 'mixpanel', allow: [ '*' ] } --> All events will be sent
     * 4. { name: 'mixpanel', allow: [ 'site.' ] } --> All site events will be sent
     * 5. { name: 'mixpanel', allow: [ '*' ], deny: [ 'site.login.', 'app.user.' ] } --> Do not send site.login.* and app.user.* events
     * 6. { name: 'mixpanel', deny: [ 'user.collab.' ] } --> Do not send user.collab.* events
     * @param consumer target event consumer
     * @param eventName event name
     */
    shouldTrack(consumerConfig, eventName) {
        const config = Object.assign({}, this.defaultConsumerRule, consumerConfig);
        const denyOptions = config.deny;
        const allowOptions = config.allow;
        if (!(allowOptions.filter(c => c === '*').length > 0 || allowOptions.filter(c => eventName.indexOf(c) > -1).length > 0)) {
            return false;
        }
        if (denyOptions.filter(c => c === '*').length > 0 ||
            denyOptions.filter(c => eventName.indexOf(c) > -1).length > 0) {
            return false;
        }
        return true;
    }
}
exports.Siddi = Siddi;
var browser_2 = require("./consumers/browser");
Object.defineProperty(exports, "BrowserConsumers", { enumerable: true, get: function () { return browser_2.Consumers; } });
var node_1 = require("./consumers/node");
Object.defineProperty(exports, "ServerConsumers", { enumerable: true, get: function () { return node_1.Consumers; } });
//# sourceMappingURL=siddi.js.map